@@ -4,7 +4,7 @@
  *
  *    High-level interface implementation
  *
- *  Copyright 1996-1998 by
+ *  Copyright 1996-1999 by
  *  David Turner, Robert Wilhelm, and Werner Lemberg.
  *
  *  This file is part of the FreeType project, and may only be used,
@@ -23,6 +23,8 @@
  *
  ******************************************************************/
 
+#include "ttconfig.h"
+
 #include "freetype.h"
 #include "ttengine.h"
 #include "ttcalc.h"
@@ -58,6 +60,33 @@
 
 
 
+/*******************************************************************
+ *
+ *  Function    :  TT_FreeType_Version
+ *
+ *  Description :  Returns the major and minor version of the library.
+ *
+ *  Input  :  major, minor addresses
+ *
+ *  Output :  Error code.
+ *
+ *  MT-Note : YES!
+ *
+ ******************************************************************/
+
+  EXPORT_FUNC
+  TT_Error  TT_FreeType_Version( int  *major, int  *minor )
+  {
+    if ( !major || !minor )
+      return TT_Err_Invalid_Argument;
+
+    *major = TT_FREETYPE_MAJOR;
+    *minor = TT_FREETYPE_MINOR;
+
+    return TT_Err_Ok;
+  }
+
+
 /*******************************************************************
  *
  *  Function    : TT_Init_FreeType
@@ -875,9 +904,9 @@
     ins->metrics.y_ppem    = pixelHeight;
     ins->metrics.pointSize = pointSize;
 
-    ins->metrics.x_scale1 = ins->metrics.x_ppem * 64;
+    ins->metrics.x_scale1 = ins->metrics.x_ppem * 64L;
     ins->metrics.x_scale2 = ins->owner->fontHeader.Units_Per_EM;
-    ins->metrics.y_scale1 = ins->metrics.y_ppem * 64;
+    ins->metrics.y_scale1 = ins->metrics.y_ppem * 64L;
     ins->metrics.y_scale2 = ins->owner->fontHeader.Units_Per_EM;
 
     ins->valid = FALSE;
@@ -1263,7 +1292,7 @@
 
 /*******************************************************************
  *
- *  Function    :  TT_Get_Big_Glyph_Metrics
+ *  Function    :  TT_Get_Glyph_Big_Metrics
  *
  *  Description :  Extracts the glyph's big metrics information.
  *
@@ -1857,7 +1886,7 @@
       return TT_Err_Invalid_Face_Handle;
 
     if ( charmapIndex >= faze->numCMaps )
-      return TT_Err_Bad_Argument;
+      return TT_Err_Invalid_Argument;
 
     cmap = faze->cMaps + charmapIndex;
 
@@ -1899,7 +1928,7 @@
       return TT_Err_Invalid_Face_Handle;
 
     if ( charmapIndex >= faze->numCMaps )
-      return TT_Err_Bad_Argument;
+      return TT_Err_Invalid_Argument;
 
     cmap = faze->cMaps + charmapIndex;
 
@@ -2039,7 +2068,7 @@
       return TT_Err_Invalid_Face_Handle;
 
     if ( nameIndex >= faze->nameTable.numNameRecords )
-      return TT_Err_Bad_Argument;
+      return TT_Err_Invalid_Argument;
 
     namerec = faze->nameTable.names + nameIndex;
 
@@ -2087,7 +2116,7 @@
       return TT_Err_Invalid_Face_Handle;
 
     if ( nameIndex >= faze->nameTable.numNameRecords )
-      return TT_Err_Bad_Argument;
+      return TT_Err_Invalid_Argument;
 
     namerec = faze->nameTable.names + nameIndex;
 
@@ -2102,8 +2131,7 @@
  *
  *  Function    :  TT_Get_Font_Data
  *
- *  Description :  Loads any font table in client memory.  Used by
- *                 the TT_Get_Font_Data().
+ *  Description :  Loads any font table into client memory.
  *
  *  Input  :  face     Face object to look for.
  *
@@ -2122,7 +2150,7 @@
  *
  *                       if length == NULL:
  *                             Load the whole table.  Returns an
- *                             an error if 'offset' != 0.
+ *                             error if 'offset' != 0.
  *
  *                       if *length == 0 :
  *                             Exit immediately, returning the
